####
CCAF
####

Ten derde maakt u een opmerking over de 7 x 24 uurs bereikbaarheid.
Inderdaad heeft de Nederlandse GGZ besloten om de bereikbaarheid buiten de
kantoor uren te laten regelen door een afdeling spoedeisende GGZ
(ok wel de 24 uurs dienst of de crisidienst genoemd). 

In de USA heeft men een dergelijk voorziening in veel regio's niet. 
Dan moet een ACT-team dus zelf crisisdienst bieden aan zijn eigen clienten.
Maar in Nederland is dat dus beter geregeld en is de 7 x 24 uurs dienst 
goed toegankelijk. Bovendien hebben de patienten van een FACT-team 
(net als andere GGZ clienten) meestal een behandelplan met een zogenaamde 
"crisis" module of crisisplan. De dienstdoende psychiater of SPV-er van de 
24-uurs dienst kan zo in het dossier van de patient opzoeken wat de afspraken 
zijn in geval van crisis.

U geeft aan det het van belang is dat je ook in crisis door een bekende
hulpverlener wordt gezien. Dat argument delen wij graag. Maar naar onze
indruk lukt dat binnen FACT meestal ook goed, doordat wij bijna alle
(dreigende) crisisgevallen in alle rust door de eigen hulpverlener binnen
kantooruren kunnen laten oplossen. Regio's waar FACT goed is ingevoerd
hebben aanzienlijk  minder crisis vragen in de avond, nacht en weekend uren
vanuit de FACT doelgroep.

Op grond van al deze argumenten en bevindingen is besloten dat FACT teams
geen eigen 24-uurs bereikbaarheid hebben. In veel gevallen is er wel
bereikbaarheid op zaterdag en zondag geregeld. Wat dat betreft zijn wij het
geheel met u eens dat voorkomen beter is dan genezen!

- J.R. van Veldhuizen, voorzitter Stichting CCAF

"Hier vond men dat alleen in regio’s waar teams werkten met optimale 24-uursbereikbaarheid het aantal opnames met 20% verminderde en de opnameduur
Regio’s met teams die deze 7*24 uur bereikbaarheid niet hadden georganiseerd, lieten geen reductie in aantal opnames of opnameduur zien."

* http://www.tijdschriftvoorpsychiatrie.nl/issues/434/articles/8318
